from pydantic_settings import BaseSettings


class Settings(BaseSettings):
    IS_DEBUG: bool = False
    DATABASE_URL: str = ""

    class Config:
        env_file = ".env"
        extra = "ignore"


config = Settings()



from typing import Annotated, Literal

from pydantic import Field


ChartNumberType = Annotated[str, Field(
    description="차트번호(8자리 숫자)", max_length=8)]
SymdType = Annotated[str, Field(description="시작일자(YYYYMMDD)", min_length=8, max_length=8)]
EymdType = Annotated[str, Field(description="종료일자(YYYYMMDD)", min_length=8, max_length=8)]

LdlItemType = Literal[
    "장기요양등급", "혼수", "섬망", "망상", "단기기억력장애",
              "인식기술", "이해시키는능력", "의사표현"]
InpatientGroupType = Annotated[
    Literal["최고도", "고도", "중도", "경도", "선택입원"],
    Field(description="장기요양 입원군"),
]



from typing import Optional

from sqlalchemy import String
from sqlalchemy.orm import DeclarativeBase

from cs_mcp.db.sqlalchemy import mc, M


class Jy(DeclarativeBase):
  """Base Jy model class that will be dynamically configured"""

  # 테이블 속성을 제거하여 추상 클래스로 만듦

  jy_auto: M[Optional[int]] = mc(
      default=None,
      primary_key=True,
      autoincrement=True
  )
  jy_jrauto: M[Optional[int]] = mc(default=None)
  jy_saup: M[str] = mc(String(2))
  jy_weibgu: M[str] = mc(String(1))
  jy_chart: M[str] = mc(String(8))
  jy_yuhyung: M[str] = mc(String(2))
  jy_jinchal: M[str] = mc(String(2))
  jy_dd: M[str] = mc(String(2))
  jy_ymd: M[str] = mc(String(8))
  jy_dup: M[int] = mc()
  jy_mcauto: M[Optional[int]] = mc(default=None)
  jy_yscode: M[Optional[str]] = mc(String(20), default=None)
  jy_myung: M[Optional[str]] = mc(String(255), default=None)
  jy_gu: M[Optional[str]] = mc(String(1), default=None)
  jy_wecode: M[Optional[str]] = mc(String(2), default=None)
  jy_hcode: M[Optional[str]] = mc(String(2), default=None)
  jy_mcode: M[Optional[str]] = mc(String(2), default=None)
  jy_danga: M[Optional[float]] = mc(default=None)
  jy_jumsu: M[Optional[float]] = mc(default=None)
  jy_ilto: M[Optional[float]] = mc(default=None)
  jy_haesu: M[Optional[int]] = mc(default=None)
  jy_chongto: M[Optional[int]] = mc(default=None)
  jy_htoyak: M[Optional[float]] = mc(default=None)
  jy_yongbup: M[Optional[str]] = mc(String(100), default=None)
  jy_simya: M[Optional[str]] = mc(String(1), default=None)
  jy_extendcode: M[Optional[str]] = mc(String(150), default=None)
  jy_gyobu: M[Optional[int]] = mc(default=None)
  jy_kumak: M[Optional[float]] = mc(default=None)
  jy_gumymd: M[Optional[str]] = mc(String(8), default=None)
  jy_changeymd: M[Optional[str]] = mc(String(8), default=None)
  jy_gschk: M[Optional[str]] = mc(String(1), default=None)
  jy_username: M[Optional[str]] = mc(String(20), default=None)
  jy_giwang: M[Optional[str]] = mc(String(1), default=None)
  jy_dpgubun: M[Optional[str]] = mc(String(2), default=None)
  jy_dpcode: M[Optional[str]] = mc(String(5), default=None)
  jy_sutakkiho: M[Optional[str]] = mc(String(8), default=None)
  jy_send: M[Optional[str]] = mc(String(1), default=None)
  jy_bcode: M[Optional[str]] = mc(String(2), default=None)
  jy_jcode: M[Optional[str]] = mc(String(2), default=None)
  jy_bubcode: M[str] = mc(String(2))
  jy_chamgo: M[Optional[str]] = mc(String(255), default=None)
  jy_bs: M[Optional[str]] = mc(String(1), default=None)
  jy_rilto: M[Optional[float]] = mc(default=None)
  jy_milto: M[Optional[float]] = mc(default=None)
  jy_lilto: M[Optional[float]] = mc(default=None)
  jy_dilto: M[Optional[float]] = mc(default=None)
  jy_bilto: M[Optional[float]] = mc(default=None)
  jy_ybchasu: M[Optional[str]] = mc(String(20), default=None)
  jy_etc1: M[Optional[str]] = mc(String(255), default=None)
  jy_etc2: M[Optional[str]] = mc( String(255),default=None)
  jy_etc3: M[Optional[str]] = mc( String(255),default=None)
  jy_etc4: M[Optional[str]] = mc( String(255),default=None)
  jy_etc5: M[Optional[str]] = mc( String(255),default=None)
  jy_dc: M[str] = mc(String(1))
  jy_orderday: M[Optional[str]] = mc(String(20), default=None)
  jy_orderchongto: M[Optional[int]] = mc(default=None)
  jy_ordercount: M[int] = mc()
  jy_tewonyak: M[Optional[str]] = mc(String(1), default=None)
  jy_ogu: M[Optional[str]] = mc(String(1), default=None)
  jy_owecode: M[Optional[str]] = mc(String(2), default=None)
  jy_oilto: M[Optional[float]] = mc(default=None)
  jy_ohaesu: M[Optional[int]] = mc(default=None)
  jy_ochongto: M[Optional[int]] = mc(default=None)
  jy_oyongbup: M[Optional[str]] = mc(String(100), default=None)
  jy_osimya: M[Optional[str]] = mc(String(1), default=None)
  jy_ogonghyu: M[Optional[str]] = mc(String(1), default=None)
  jy_ostat: M[Optional[str]] = mc(String(1), default=None)
  jy_ogschk: M[Optional[str]] = mc(String(1), default=None)
  jy_oextendcode: M[Optional[str]] = mc(String(150), default=None)
  jy_ochamgo: M[Optional[str]] = mc(String(255), default=None)
  jy_ogiwang: M[Optional[str]] = mc(String(1), default=None)
  jy_odpgubun: M[Optional[str]] = mc(String(2), default=None)
  jy_odpcode: M[Optional[str]] = mc(String(5), default=None)
  jy_osend: M[Optional[str]] = mc(String(1), default=None)
  jy_docdate: M[Optional[str]] = mc(String(20), default=None)
  jy_dcdate: M[Optional[str]] = mc(String(20), default=None)
  jy_pudate: M[Optional[str]] = mc(String(255), default=None)
  jy_actdate: M[Optional[str]] = mc(String(255), default=None)
  jy_docuser: M[Optional[str]] = mc(String(20), default=None)
  jy_upuser: M[Optional[str]] = mc(String(20), default=None)
  jy_dcuser: M[Optional[str]] = mc(String(20), default=None)
  jy_puuser: M[Optional[str]] = mc(String(255), default=None)
  jy_actuser: M[Optional[str]] = mc(String(255), default=None)
  jy_etc6: M[Optional[str]] = mc(String(255), default=None)
  jy_etc7: M[Optional[str]] = mc(String(255), default=None)
  jy_etc8: M[Optional[str]] = mc(String(255), default=None)
  jy_etc9: M[Optional[str]] = mc(String(255), default=None)
  jy_etc10: M[Optional[str]] = mc(String(255), default=None)
  jy_etc11: M[Optional[str]] = mc(String(255), default=None)
  jy_etc12: M[Optional[str]] = mc(String(255), default=None)
  jy_etc13: M[Optional[str]] = mc(String(255), default=None)
  jy_etc14: M[Optional[str]] = mc(String(255), default=None)
  jy_etc15: M[Optional[str]] = mc(String(255), default=None)
  jy_ordernumber: M[Optional[str]] = mc(String(30), default=None)
  jy_durnumber: M[Optional[str]] = mc(String(20), default=None)
  jy_etc16: M[Optional[str]] = mc(String(255), default=None)
  jy_etc17: M[Optional[str]] = mc(String(255), default=None)
  jy_etc18: M[Optional[str]] = mc(String(255), default=None)
  jy_etc19: M[Optional[str]] = mc(String(255), default=None)
  jy_etc20: M[Optional[str]] = mc(String(255), default=None)
  jy_daycnt: M[int] = mc()
  jy_changeorder: M[Optional[str]] = mc(String(1), default=None)
  jy_notpulv: M[Optional[str]] = mc(String(1), default=None)
  jy_onotpulv: M[Optional[str]] = mc(String(1), default=None)
  jy_etc21: M[Optional[str]] = mc(String(255), default=None)
  jy_etc22: M[Optional[str]] = mc(String(255), default=None)
  jy_etc23: M[Optional[str]] = mc(String(255), default=None)
  jy_etc24: M[Optional[str]] = mc(String(255), default=None)
  jy_etc25: M[Optional[str]] = mc(String(255), default=None)
  jy_etc26: M[str] = mc(String(50))
  jy_etc27: M[str] = mc(String(50))
  jy_etc28: M[str] = mc(String(50))
  jy_etc29: M[str] = mc(String(50))
  jy_etc30: M[str] = mc(String(50))
  jy_jgubun: M[str] = mc(String(10))
  jy_kind: M[str] = mc(String(1))
  jy_time1: M[str] = mc(String(4))
  jy_chk1: M[str] = mc(String(1))
  jy_user1: M[str] = mc(String(10))
  jy_time2: M[str] = mc(String(4))
  jy_chk2: M[str] = mc(String(1))
  jy_user2: M[str] = mc(String(10))
  jy_time3: M[str] = mc(String(4))
  jy_chk3: M[str] = mc(String(1))
  jy_user3: M[str] = mc(String(10))
  jy_time4: M[str] = mc(String(4))
  jy_chk4: M[str] = mc(String(1))
  jy_user4: M[str] = mc(String(10))
  jy_time5: M[str] = mc(String(4))
  jy_chk5: M[str] = mc(String(1))
  jy_user5: M[str] = mc(String(10))
  jy_time6: M[str] = mc(String(4))
  jy_chk6: M[str] = mc(String(1))
  jy_user6: M[str] = mc(String(10))
  jy_time7: M[str] = mc(String(4))
  jy_chk7: M[str] = mc(String(1))
  jy_user7: M[str] = mc(String(10))
  jy_time8: M[str] = mc(String(4))
  jy_chk8: M[str] = mc(String(1))
  jy_user8: M[str] = mc(String(10))
  jy_time9: M[str] = mc(String(4))
  jy_chk9: M[str] = mc(String(1))
  jy_user9: M[str] = mc(String(10))
  jy_time10: M[str] = mc(String(4))
  jy_chk10: M[str] = mc(String(1))
  jy_user10: M[str] = mc(String(10))



from cs_mcp.db.models.base import Base
from typing import Optional
from cs_mcp.db.sqlalchemy import mc, M
from sqlalchemy import String


class ProgressNote(Base):
  __tablename__ = "progressnote"  # type: ignore

  prog_auto: M[Optional[int]] = mc(
      default=None, primary_key=True, autoincrement=True
  )
  prog_gubun: M[str] = mc(String(2))
  prog_saup: M[str] = mc(String(2))
  prog_weibgu: M[str] = mc(String(1))
  prog_chart: M[str] = mc(String(8))
  prog_yuhyung: M[str] = mc(String(2))
  prog_jinchal: M[str] = mc(String(2))
  prog_ymd: M[str] = mc(String(8))
  prog_ibymd: M[str] = mc(String(8))
  prog_dup: M[int] = mc()
  prog_time: M[Optional[str]] = mc(String(6), default=None)
  prog_progress: M[Optional[str]] = mc(default=None)
  prog_rtf: M[Optional[str]] = mc(default=None)
  prog_username: M[Optional[str]] = mc(String(20), default=None)
  prog_etc1: M[Optional[str]] = mc(String(255), default=None)
  prog_etc2: M[Optional[str]] = mc(String(255), default=None)
  prog_etc3: M[Optional[str]] = mc(String(255), default=None)
  prog_etc4: M[Optional[str]] = mc(String(255), default=None)
  prog_etc5: M[Optional[str]] = mc(String(255), default=None)
  prog_dc: M[str] = mc(String(1))
  prog_indate: M[Optional[str]] = mc(String(20), default=None)
  prog_update: M[Optional[str]] = mc(String(255), default=None)
  prog_dcdate: M[Optional[str]] = mc(String(255), default=None)
  prog_inuser: M[Optional[str]] = mc(String(20), default=None)
  prog_upuser: M[Optional[str]] = mc(String(20), default=None)
  prog_dcuser: M[Optional[str]] = mc(String(20), default=None)
  prog_insign: M[Optional[bytes]] = mc(default=None)
  prog_upsign: M[Optional[bytes]] = mc(default=None)
  prog_dcsign: M[Optional[bytes]] = mc(default=None)
  prog_incert: M[Optional[str]] = mc(default=None)
  prog_upcert: M[Optional[str]] = mc(default=None)
  prog_dccert: M[Optional[str]] = mc(default=None)
  prog_etc6: M[Optional[str]] = mc(String(255), default=None)
  prog_etc7: M[Optional[str]] = mc(String(255), default=None)
  prog_etc8: M[Optional[str]] = mc(String(255), default=None)
  prog_etc9: M[Optional[str]] = mc(String(255), default=None)
  prog_etc10: M[Optional[str]] = mc(String(255), default=None)



from sqlalchemy import String
from cs_mcp.db.models.base import Base
from typing import Optional
from cs_mcp.db.sqlalchemy import mc, M


class Vs(Base):
  __tablename__ = "vs"  # type: ignore
  vs_auto: M[Optional[int]] = mc(default=None, primary_key=True)
  vs_saup: M[str] = mc(String(2))
  vs_chart: M[str] = mc(String(8))
  vs_ibymd: M[str] = mc(String(8))
  vs_ymd: M[str] = mc(String(8))
  vs_time: M[str] = mc(String(6))
  vs_teymd: M[Optional[str]] = mc(String(8), default=None)
  vs_yuhyung: M[Optional[str]] = mc(String(2), default=None)
  vs_bscode: M[Optional[str]] = mc(String(9), default=None)
  vs_jinchal: M[Optional[str]] = mc(String(2), default=None)
  vs_suname: M[Optional[str]] = mc(String(50), default=None)
  vs_jumin: M[Optional[str]] = mc(String(48), default=None)
  vs_nurse: M[Optional[str]] = mc(String(10), default=None)
  vs_weymd: M[Optional[str]] = mc(String(8), default=None)
  vs_hulap1: M[Optional[str]] = mc(String(10), default=None)
  vs_hulap2: M[Optional[str]] = mc(String(10), default=None)
  vs_maekbak: M[Optional[str]] = mc(String(10), default=None)
  vs_cheon: M[Optional[str]] = mc(String(10), default=None)
  vs_hohup: M[Optional[str]] = mc(String(10), default=None)
  vs_weight: M[Optional[str]] = mc(String(10), default=None)
  vs_height: M[Optional[str]] = mc(String(10), default=None)
  vs_bmi: M[Optional[str]] = mc(String(10), default=None)
  vs_intake: M[Optional[str]] = mc(String(10), default=None)
  vs_urine: M[Optional[str]] = mc(String(16), default=None)
  vs_stools: M[Optional[str]] = mc(String(16), default=None)
  vs_fluids: M[Optional[str]] = mc(String(16), default=None)
  vs_blood: M[Optional[str]] = mc(String(16), default=None)
  vs_aspiration: M[Optional[str]] = mc(String(16), default=None)
  vs_drainage: M[Optional[str]] = mc(String(16), default=None)
  vs_vomitus: M[Optional[str]] = mc(String(16), default=None)
  vs_username: M[Optional[str]] = mc(String(20), default=None)
  vs_glucose: M[Optional[str]] = mc(String(20), default=None)
  vs_spo2: M[Optional[str]] = mc(String(20), default=None)
  vs_etc1: M[Optional[str]] = mc(String(255), default=None)
  vs_etc2: M[Optional[str]] = mc(String(255), default=None)
  vs_etc3: M[Optional[str]] = mc(String(255), default=None)
  vs_etc4: M[Optional[str]] = mc(String(255), default=None)
  vs_etc5: M[Optional[str]] = mc(String(255), default=None)
  vs_dc: M[str] = mc(String(1), default="0")
  vs_indate: M[Optional[str]] = mc(String(20), default=None)
  vs_update: M[Optional[str]] = mc(String(20), default=None)
  vs_dcdate: M[Optional[str]] = mc(String(20), default=None)
  vs_upuser: M[Optional[str]] = mc(String(20), default=None)
  vs_dcuser: M[Optional[str]] = mc(String(20), default=None)
  vs_insign: M[Optional[bytes]] = mc(default=None)
  vs_upsign: M[Optional[bytes]] = mc(default=None)
  vs_dcsign: M[Optional[bytes]] = mc(default=None)
  vs_incert: M[Optional[str]] = mc(default=None)
  vs_upcert: M[Optional[str]] = mc(default=None)
  vs_dccert: M[Optional[str]] = mc(default=None)
  vs_etc6: M[Optional[str]] = mc(String(255), default=None)
  vs_etc7: M[Optional[str]] = mc(String(255), default=None)
  vs_etc8: M[Optional[str]] = mc(String(255), default=None)
  vs_etc9: M[Optional[str]] = mc(String(255), default=None)
  vs_etc10: M[Optional[str]] = mc(String(255), default=None)
  vs_shift: M[Optional[str]] = mc(String(1), default="D")



from sqlalchemy import MetaData
from sqlalchemy.orm import DeclarativeBase

# 1. MetaData 객체 생성 시 schema 지정
#    (모든 테이블이 동일한 스키마를 공유할 경우)
SCHEMA_NAME = "cs2002"
metadata = MetaData(schema=SCHEMA_NAME)


class Base(DeclarativeBase):
  metadata = metadata

  def to_dict(self):
    return {c.name: getattr(self, c.name) for c in self.__table__.columns}


from typing import Optional 
from sqlalchemy import String

from cs_mcp.db.models.base import Base
from cs_mcp.db.sqlalchemy import mc, M


class Ns(Base):
  __tablename__ = "ns"  # type: ignore

  ns_auto: M[Optional[int]] = mc(
      default=None, primary_key=True, autoincrement=True
  )
  ns_chart: M[str] = mc(String(8))
  ns_ymd: M[str] = mc(String(50))
  ns_neyong1: M[str] = mc()
  ns_neyong2: M[str] = mc()



from cs_mcp.configs import config
from cs_mcp.tools import advice_tools, jy_tools, ltcdrglist_tools, patient_info_tools, ns_tools, progress_note_tools, util_tools, vs_tools


def run_mcp():
  from fastmcp import FastMCP

  mcp = FastMCP("ClickMCP")

  patient_info_tools(mcp)
  advice_tools(mcp)
  ltcdrglist_tools(mcp)
  ns_tools(mcp)
  vs_tools(mcp)
  progress_note_tools(mcp)
  jy_tools(mcp)
  util_tools(mcp)
  if config.IS_DEBUG:
    mcp.run(
        transport="streamable-http",
        path="/mcp",  # Adjust the path as needed
        port=8001,
    )
  else:
    mcp.run(
        transport="stdio",  # Use stdio for standard input/output
    )



from datetime import datetime
from typing import Annotated, Any, Literal
from fastmcp import FastMCP
from pydantic import Field
from cs_mcp.db.services import ltcdrg_service
from cs_mcp.tools.types import ChartNumberType, EymdType, InpatientGroupType, LdlItemType, SymdType


def ltcdrglist_tools(mcp: FastMCP[Any]):
  @mcp.tool()
  async def search_ltcdrg_items(
          symd: SymdType,
          eymd: EymdType,
          items: list[LdlItemType]):
    """
    장기요양 점검표에서 지정한 기간(symd~eymd) 내에 특정 항목(item)이 존재하는 경우를 조회합니다.
    """

    return await ltcdrg_service.search_ltcdrg_items(symd, eymd, items)

  @mcp.tool()
  async def get_adl_scores(
      charts: Annotated[list[ChartNumberType], Field(description="차트번호 목록")],
      symd: SymdType,
      eymd: EymdType,
  ):
    """장기요양 ADL 점수 조회

    args:
        charts:
          - 차트번호 목록
          - 빈 목록([])일 경우, 지정된 기간의 모든 환자 조회
    """

    return await ltcdrg_service.get_adl_scores(charts, symd, eymd)

  @mcp.tool()
  async def compare_ltcdrg(
      id_a: Annotated[int, Field(description="비교할 ID")],
      id_b: Annotated[int, Field(description="비교할 ID")],
  ):
    """장기요양점검표를 비교합니다.

    Args:
        id_a: First record ID.
        id_b: Second record ID.

    Output:
        Markdown table showing only the fields with different values, including field descriptions.
    """

    return await ltcdrg_service.compare_ltcdrg(id_a, id_b)

  @mcp.tool()
  async def get_ltcdrg_dates(
      chart_number: ChartNumberType,
  ):
    """특정 환자의 장기요양정검표 작성날짜를 조회합니다.

    args:
        chart_number: 차트번호(8자리 숫자)
    returns:
        Id: ID
        일자: 작성일자
        유형: 유형
    """
    return await ltcdrg_service.get_ltcdrg_dates(chart_number)

  @mcp.tool()
  async def compare_adl(
      symd_a: Annotated[str, Field(description="StartDate A(YYYYMMMM)", max_length=8)],
      eymd_a: Annotated[str, Field(description="EndDate A(YYYYMMMM)", max_length=8)],
      symd_b: Annotated[str, Field(description="StartDate B(YYYYMMMM)", max_length=8)],
      eymd_b: Annotated[str, Field(description="EndDate B(YYYYMMMM)", max_length=8)],
      status: Literal["Increase", "Decrease", "Unchanged"] = "Increase",
  ):
    """장기요양점검표 ADL 점수를 비교합니다.

    args:
      status: Status of comparison, "Increase" (default), "Decrease", or "Unchanged".
        - "Increase": Show records where ADL score increased from period A to B.
        - "Decrease": Show records where ADL score decreased from period A to B.
        - "Unchanged": Show records where ADL score remained the same from period A to B.
    """

    return await ltcdrg_service.compare_adl(symd_a, eymd_a, symd_b, eymd_b, status)

  @mcp.tool()
  async def get_inpatient_groups(
      symd: Annotated[str, Field(description="StartDate(YYYYMMMM)", max_length=8)],
      eymd: Annotated[str, Field(description="EndDate(YYYYMMMM)", max_length=8)],
      group: InpatientGroupType,
  ):
    """특정 기간 내 장기요양 입원군(군 분류)을 조회합니다.

    args:
        group: 장기요양 의료 등급 선택
            - None (default): 모든 등급 조회
            - "최고도": 최고도 등급
            - "고도": 고도 등급
            - "중도": 중도 등급
            - "경도": 경도 등급
            - "선택입원": 선택입원 등급
    returns:
        Markdown table with 차트번호, 시작일자, 장기요양등급, 군 분류
    """

    return await ltcdrg_service.get_inpatient_groups(symd, eymd, group)

  @mcp.tool()
  async def compare_inpatient_group(
      symd_a: Annotated[str, Field(description="StartDate A(YYYYMMMM)", max_length=8)],
      eymd_a: Annotated[str, Field(description="EndDate A(YYYYMMMM)", max_length=8)],
      group_a: InpatientGroupType,
      symd_b: Annotated[str, Field(description="StartDate B(YYYYMMMM)", max_length=8)],
      eymd_b: Annotated[str, Field(description="EndDate B(YYYYMMMM)", max_length=8)],
      group_b: InpatientGroupType,
      status: Literal["Increase", "Decrease", "Unchanged"] = "Increase",
  ):
    """장기요양 입원군(군 분류)을 비교합니다.

    args:
      status: Status of comparison, "Increase" (default), "Decrease", or "Unchanged".
        - "Increase": 등급이 높아진 경우 (예: 고도 → 최고도)
        - "Decrease": 등급이 낮아진 경우 (예: 최고도 → 고도)
        - "Unchanged": 등급이 변경되지 않은 경우
    """

    return await ltcdrg_service.compare_inpatient_group(symd_a, eymd_a, group_a, symd_b, eymd_b, group_b, status)

  @mcp.tool()
  async def check_dementia_due_date(
      dementia_check_type: Literal["MMSE", "GDR", "CDS"] = "MMSE",
      reference: Annotated[str, Field(
          description="YYYYMMDD", max_length=8)] = datetime.now().strftime("%Y%m%d"),
      check_months: Annotated[int, Field(
          description="Check Terms(Default: 6 Months)", ge=1, le=12)] = 6,
      prior_to: Annotated[int, Field(
          description="마감 x일 전(Default: 14 days)", ge=1, le=30)] = 14,
  ):
    """장기요양점검표 치매검사 만료일자를 확인합니다.

    args:
      reference: 기준일자(Default 오늘 날짜)
      previousMonth: 이전 월 기간(Default 6개월)
      dueDays: 도래일수(Default 14일)

    **참고**: 별도 정보가 없는 경우, Default 값으로 사용
    """

    return await ltcdrg_service.check_dementia_due_date(dementia_check_type, reference, check_months, prior_to)



import pandas as pd

from typing import Any
from fastmcp import FastMCP
from sqlalchemy import select

from cs_mcp.db.dependencies import get_db
from cs_mcp.db.models import Vs
from cs_mcp.tools.types import ChartNumberType, EymdType, SymdType


def vs_tools(mcp: FastMCP[Any]):
  @mcp.tool()
  async def get_vitalsigns(
      chart: ChartNumberType,
      symd: SymdType,
      eymd: EymdType,
  ):
    """차트번호로 바이탈사인을 가져온다."""

    async with get_db() as session:

      # session 에서 wj 객체를 가져온다.
      vitals = await session.execute(
          select(Vs).where(
              (Vs.vs_chart == chart) & (
                  Vs.vs_ymd >= symd) & (Vs.vs_ymd <= eymd)
          )
      )
      vitalsigns = vitals.scalars()

    data = [
        {
            "일자": vs.vs_ymd,
            "작성시간": vs.vs_time,
            "수축기 혈압": vs.vs_hulap2,
            "이완기 혈압": vs.vs_hulap1,
            "맥박": vs.vs_maekbak,
            "호흡수": vs.vs_hohup,
            "체온": vs.vs_cheon,
            "체중": vs.vs_weight,
            "신장": vs.vs_height,
            "산소포화도": vs.vs_spo2,
            "섭취량": vs.vs_intake,
            "소변량": vs.vs_urine,
            "혈액량": vs.vs_blood,
            "흡인량": vs.vs_aspiration,
            "배액량": vs.vs_drainage,
            "구토량": vs.vs_vomitus,
            "작성자": vs.vs_username,
        }
        for vs in vitalsigns
    ]

    df = pd.DataFrame(data)
    return df.to_markdown(index=False)

  # @mcp.tool()
  # def write_batch_vital_sign_tool(
  #     vs_data: dict[ChartNumberType, BatchVitalSignData],
  # ):
  #   """바이탈사인을 일괄 입력합니다.

  #   Args:
  #       vs_data: 차트번호를 키로 하고 바이탈사인 데이터를 값으로 하는 딕셔너리입니다.
  #           - 키: 환자의 차트번호(8자리 숫자)
  #           - 값: BatchVitalSignData 객체로 다음 필드를 포함할 수 있습니다:
  #               - hulap2: 수축기 혈압 (mmHg)
  #               - hulap1: 이완기 혈압 (mmHg)
  #               - maekbak: 맥박 (회/분)
  #               - hohup: 호흡수 (회/분)
  #               - cheon: 체온 (°C)
  #               - weight: 체중 (kg)
  #               - height: 신장 (cm)
  #               - spo2: 산소포화도 (%)
  #               - intake: 섭취량 (ml)
  #               - urine: 소변량 (ml)
  #               - blood: 혈액량 (ml)
  #               - aspiration: 흡인량 (ml)
  #               - drainage: 배액량 (ml)
  #               - vomitus: 구토량 (ml)

  #   Returns:
  #       str: 성공 시 "성공" 메시지를 반환합니다.

  #   Example:
  #       {"00000123": {"hulap2": "120", "hulap1": "80", "cheon": "36.5"}}
  #   """

  #   return "성공"




from typing import Any
from fastmcp import FastMCP
import pandas as pd
from sqlalchemy import select

from cs_mcp.db.dependencies import get_db
from cs_mcp.tools.types import SymdType, ChartNumberType, EymdType


def progress_note_tools(mcp: FastMCP[Any]):
  @mcp.tool()
  async def get_progressnotes(
      chart: ChartNumberType,
      symd: SymdType,
      eymd: EymdType,
  ):
    """차트번호로 경과기록을 가져온다."""
    from cs_mcp.db.models import ProgressNote

    async with get_db() as session:

      # session 에서 wj 객체를 가져온다.
      progress = await session.execute(
          select(ProgressNote).where(
              (ProgressNote.prog_chart == chart)
              & (ProgressNote.prog_ymd >= symd)
              & (ProgressNote.prog_ymd <= eymd)
              & (ProgressNote.prog_dc != "1")
              & (ProgressNote.prog_gubun == "A")
          )
      )
      progresses = progress.scalars().all()

    datas = [
        {
            "일자": prog.prog_ymd,
            "작성자": prog.prog_username,
            "내용": prog.prog_progress,
        }
        for prog in progresses
    ]
    df = pd.DataFrame(datas)
    return df.to_markdown(index=False)



inpatient_group_dict = {
    "최고도": "A1",
    "고도": "A2",
    "중도": "A3",
    "경도": "A6",
    "선택입원": "A7",
}

ldl_description_dict = {
    "ldl_a10_a": "담배를 피우는지 여부 (0: 아니오, 1: 예)",
    "ldl_a10_b": "술을 자주 마시는지 여부 (0: 아니오, 1: 예)",
    "ldl_a10_c": "운동(주4일이상, 30분이상)여부 (0: 아니오, 1: 예)",
    "ldl_a10_d": "식사(하루 세끼) 챙겨먹는지 여부 (0: 아니오, 1: 예)",
    "ldl_a11": "장기요양등급 및 신청 (1: 해당없음, 2: 미신청, 3: 신청중, 4: 신청하였으나 인정 못 받음, 5: 등급 내자, 6: 등급 외자)",
    "ldl_a12_a": "장기요양등급 (1: 1등급, 2: 2등급, 3: 3등급, 4: 4~5등급, 5: 인지지원등급, 6: 확인불가)",
    "ldl_a12_b1": "장기요양이용서비스-1. 주야간보호 (0: 미선택, 1: 선택)",
    "ldl_a12_b2": "장기요양이용서비스-2. 방문요양 (0: 미선택, 1: 선택)",
    "ldl_a12_b3": "장기요양이용서비스-3. 방문간호 (0: 미선택, 1: 선택)",
    "ldl_a12_b4": "장기요양이용서비스-4. 방문목욕 (0: 미선택, 1: 선택)",
    "ldl_a12_b5": "장기요양이용서비스-5. 단기보호 (0: 미선택, 1: 선택)",
    "ldl_a12_b6": "장기요양이용서비스-6. 복지용구 구입 및 대여 (0: 미선택, 1: 선택)",
    "ldl_a12_b7": "장기요양이용서비스-7. 시설입소 (0: 미선택, 1: 선택)",
    "ldl_a12_b8": "장기요양이용서비스-8. 기타 (0: 미선택, 1: 선택)",
    "ldl_a13": "장기요양서비스 이용의향 (0: 아니오, 1: 예)",
    "ldl_a14_a": "사회환경선별조사-응답거부 (0: 거부안함, 1: 거부)",
    "ldl_a14_b": "사회환경선별조사-식사준비, 청소 등의 도움을 줄 수 있는 사람이 없는지 여부 (0: 아니오, 1: 예)",
    "ldl_a14_c": "사회환경선별조사-전기,수도 등 공과금 미납으로 서비스 중단 고지를 받은 적이 있는지 여부 (0: 아니오, 1: 예)",
    "ldl_a14_d": "사회환경선별조사-안정적으로 거주할 집이 없어 노숙을 한 적이 있는지 여부 (0: 아니오, 1: 예)",
    "ldl_a14_e": "사회환경선별조사-병원비, 월세, 주거비, 난방비 등 비용 지불이 어려운 적이 있는지 여부 (0: 아니오, 1: 예)",
    "ldl_a14_f": "사회환경선별조사-교통수단 부족으로 진료, 복지관 등 외출이 어려웠던 적이 있는지 여부 (0: 아니오, 1: 예)",
    "ldl_a14_g": "사회환경선별조사-먹을 것이 없거나, 학대를 받는 등 긴급하게 도움이 필요한 적이 있는지 여부 (0: 아니오, 1: 예)",
    "ldl_b1": "혼수 (0: 아니오, 1: 예)",
    "ldl_b2": "섬망 (0: 없음, 1: 섬망 증상이 있으나, 지난 7일 이전에 발생함, 2: 섬망 증상이 있으나, 지난 7일 이내에 발생하였거나 악화되고 있음)",
    "ldl_c1": "단기기억력장애 (0: 정상, 1: 이상 있음, 2: 확인 불가)",
    "ldl_c2": "일상 생활사에 관해 의사결정을 할 수 있는 인식기술 (0: 스스로 일관성 있고 합리적인 의사결정을 함, 1: 새로운 상황에서만 의사결정의 어려움 있음, 2: 인식기술이 다소 손상됨, 3: 인식기술이 심하게 손상됨)",
    "ldl_c3": "이해시키는 능력 (0: 이해시킴, 1: 대부분 이해시킴, 2: 가끔 이해시킴, 3: 거의/전혀 이해시키지 못함)",
    "ldl_c4": "말로 의사표현을 할 수 있음 (0: 아니오, 1: 예)",
    "ldl_c5_a": "행동심리증상 빈도 a.망상 (0: 없음, 1: 가끔, 2: 자주, 3: 매우자주)",
    "ldl_c5_b": "행동심리증상 빈도 b.환각 (0: 없음, 1: 가끔, 2: 자주, 3: 매우자주)",
    "ldl_c5_c": "행동심리증상 빈도 c.초조/공격성 (0: 없음, 1: 가끔, 2: 자주, 3: 매우자주)",
    "ldl_c5_d": "행동심리증상 빈도 d.우울/낙담 (0: 없음, 1: 가끔, 2: 자주, 3: 매우자주)",
    "ldl_c5_e": "행동심리증상 빈도 e.불안 (0: 없음, 1: 가끔, 2: 자주, 3: 매우자주)",
    "ldl_c5_f": "행동심리증상 빈도 f.들뜬 기분/다행감 (0: 없음, 1: 가끔, 2: 자주, 3: 매우자주)",
    "ldl_c5_g": "행동심리증상 빈도 g.무감동/무관심 (0: 없음, 1: 가끔, 2: 자주, 3: 매우자주)",
    "ldl_c5_h": "행동심리증상 빈도 h.탈억제 (0: 없음, 1: 가끔, 2: 자주, 3: 매우자주)",
    "ldl_c5_i": "행동심리증상 빈도 i.과민/불안정 (0: 없음, 1: 가끔, 2: 자주, 3: 매우자주)",
    "ldl_c5_j": "행동심리증상 빈도 j.이상 운동증상 또는 반복적 행동 (0: 없음, 1: 가끔, 2: 자주, 3: 매우자주)",
    "ldl_c5_k": "행동심리증상 빈도 k.수면/야간행동 (0: 없음, 1: 가끔, 2: 자주, 3: 매우자주)",
    "ldl_c5_l": "행동심리증상 빈도 l.식욕/식습관의 변화 (0: 없음, 1: 가끔, 2: 자주, 3: 매우자주)",
    "ldl_c5_m": "행동심리증상 빈도 m.케어에 대한 저항 (0: 없음, 1: 가끔, 2: 자주, 3: 매우자주)",
    "ldl_c5_n": "행동심리증상 빈도 n.배회 (0: 없음, 1: 가끔, 2: 자주, 3: 매우자주)",
    "ldl_c6_a": "K-MMSE 검사 실시여부 (0: 아니오, 1: 예)",
    "ldl_c6_b1": "K-MMSE 점수 (0-99)",
    "ldl_c6_b2": "K-MMSE 검사일 (YYYYMMDD)",
    "ldl_c7_a": "CDR 검사 실시여부 (0: 아니오, 1: 예)",
    "ldl_c7_b1": "CDR 점수 (0-9.9)",
    "ldl_c7_b2": "CDR 검사일 (YYYYMMDD)",
    "ldl_c7_c": "GDS 검사 실시여부 (0: 아니오, 1: 예)",
    "ldl_c7_d1": "GDS 점수 (0-9)",
    "ldl_c7_d2": "GDS 검사일 (YYYYMMDD)",
    "ldl_d1": "일상생활 활동 능력 1. 옷 벗고 입기 (0: 완전자립, 1: 감독필요, 2: 약간의도움, 3:상당한도움, 4: 전적인도움, 8: 행위발생안함)",
    "ldl_d2": "일상생활 활동 능력 2. 세수하기 (0: 완전자립, 1: 감독필요, 2: 약간의도움, 3:상당한도움, 4: 전적인도움, 8: 행위발생안함)",
    "ldl_d3": "일상생활 활동 능력 3. 양치질하기 (0: 완전자립, 1: 감독필요, 2: 약간의도움, 3:상당한도움, 4: 전적인도움, 8: 행위발생안함)",
    "ldl_d4": "일상생활 활동 능력 4. 목욕하기 (0: 완전자립, 1: 감독필요, 2: 약간의도움, 3:상당한도움, 4: 전적인도움, 8: 행위발생안함)",
    "ldl_d5": "일상생활 활동 능력 5. 식사하기 (0: 완전자립, 1: 감독필요, 2: 약간의도움, 3:상당한도움, 4: 전적인도움, 8: 행위발생안함)",
    "ldl_d6": "일상생활 활동 능력 6. 체위 변경하기 (0: 완전자립, 1: 감독필요, 2: 약간의도움, 3:상당한도움, 4: 전적인도움, 8: 행위발생안함)",
    "ldl_d7": "일상생활 활동 능력 7. 일어나 앉기 (0: 완전자립, 1: 감독필요, 2: 약간의도움, 3:상당한도움, 4: 전적인도움, 8: 행위발생안함)",
    "ldl_d8": "일상생활 활동 능력 8. 옮겨 앉기 (0: 완전자립, 1: 감독필요, 2: 약간의도움, 3:상당한도움, 4: 전적인도움, 8: 행위발생안함)",
    "ldl_d9": "일상생활 활동 능력 9. 방 밖으로 나오기 (0: 완전자립, 1: 감독필요, 2: 약간의도움, 3:상당한도움, 4: 전적인도움, 8: 행위발생안함)",
    "ldl_d10": "일상생활 활동 능력 10. 화장실 사용하기 (0: 완전자립, 1: 감독필요, 2: 약간의도움, 3:상당한도움, 4: 전적인도움, 8: 행위발생안함)",
    "ldl_d11": "와상상태 여부 (0: 아니오, 1: 예)",
    "ldl_d12_a": "해당 없음",
    "ldl_d12_b": "해당 없음",
    "ldl_d12_c": "해당 없음",
    "ldl_e1": "대변조절 상태 (0: 조절할 수 있음, 1: 가끔 실금함, 2: 자주 실금함, 3. 조절 못함)",
    "ldl_e2": "소변조절 상태 (0: 조절할 수 있음, 1: 가끔 실금함, 2: 자주 실금함, 3. 조절 못함)",
    "ldl_e3_a": "배변 조절 기구 및 프로그램 a. 일정하게 짜여진 배뇨계획 (0: 미선택, 1: 선택)",
    "ldl_e3_b": "배변 조절 기구 및 프로그램 b. 방광 훈련 프로그램 (0: 미선택, 1: 선택)",
    "ldl_e3_c": "배변 조절 기구 및 프로그램 c. 규칙적 도뇨 (0: 미선택, 1: 선택)",
    "ldl_e3_d": "배변 조절 기구 및 프로그램 d. 외부(콘돔형) 카테터 (0: 미선택, 1: 선택)",
    "ldl_e3_e": "배변 조절 기구 및 프로그램 e. 패드, 팬티형 기저귀 (0: 미선택, 1: 선택)",
    "ldl_e3_f": "배변 조절 기구 및 프로그램 f. 인공루 (0: 미선택, 1: 선택)",
    "ldl_e3_g": "배변 조절 기구 및 프로그램 g. 유치도뇨관 삽입 (0: 미선택, 1: 선택)",
    "ldl_e3_g1": "해당 없음",
    "ldl_e3_g1_1": "유치도뇨관 삽입일자 (YYYYMMDD)",
    "ldl_e3_g1_2": "유치도뇨관 제거일자 (YYYYMMDD)",
    "ldl_e3_g2_1": "유치도뇨관 삽입일자 (YYYYMMDD)",
    "ldl_e3_g2_2": "유치도뇨관 제거일자 (YYYYMMDD)",
    "ldl_e3_g3_1": "유치도뇨관 삽입일자 (YYYYMMDD)",
    "ldl_e3_g3_2": "유치도뇨관 제거일자 (YYYYMMDD)",
    "ldl_e3_g4_1": "유치도뇨관 삽입일자 (YYYYMMDD)",
    "ldl_e3_g4_2": "유치도뇨관 제거일자 (YYYYMMDD)",
    "ldl_e3_g5_1": "유치도뇨관 삽입일자 (YYYYMMDD)",
    "ldl_e3_g5_2": "유치도뇨관 제거일자 (YYYYMMDD)",
    "ldl_e3_g6_1": "유치도뇨관 삽입일자 (YYYYMMDD)",
    "ldl_e3_g6_2": "유치도뇨관 제거일자 (YYYYMMDD)",
    "ldl_e3_g7_1": "유치도뇨관 삽입일자 (YYYYMMDD)",
    "ldl_e3_g7_2": "유치도뇨관 제거일자 (YYYYMMDD)",
    "ldl_e3_g8_1": "유치도뇨관 삽입일자 (YYYYMMDD)",
    "ldl_e3_g8_2": "유치도뇨관 제거일자 (YYYYMMDD)",
    "ldl_e3_g9_1": "유치도뇨관 삽입일자 (YYYYMMDD)",
    "ldl_e3_g9_2": "유치도뇨관 제거일자 (YYYYMMDD)",
    "ldl_e3_g10_1": "유치도뇨관 삽입일자 (YYYYMMDD)",
    "ldl_e3_g10_2": "유치도뇨관 제거일자 (YYYYMMDD)",
    "ldl_e3_g11": "유치도뇨관 삽입기간(g-1 ~ g-10을 제외한 삽입기간)",
    "ldl_e3_h": "배변 조절 기구 및 프로그램 h. 해당사항 없음(0: 미선택, 1: 선택)",
    "ldl_e4": "해당 없음",
    "ldl_e4_a": "배뇨일지 작성여부 (0: 아니오, 1: 예)",
    "ldl_e4_b": "배뇨일지 작성일수",
    "ldl_f1_a": "질병 및 상해 항목 a. 당뇨 (0: 미선택, 1: 선택)",
    "ldl_f1_a1_a": "혈당검사(1일 3회 이상)매일 실시 여부 (0: 아니오, 1: 예)",
    "ldl_f1_a1_b1": "공복시 혈당 (mg/dl)",
    "ldl_f1_a1_b2": "식후2시간 혈당 (mg/dl)",
    "ldl_f1_a2_a": "최근 3개월 이내에 헤모글로빈A1c(HbA1c)검사 실시 여부 (0: 아니오, 1: 예)",
    "ldl_f1_a2_b1": "b-1.HbA1c (%)",
    "ldl_f1_a2_b2": "검사일: (YYYYMMDD)",
    "ldl_f1_b": "질병 및 상해 항목 b. 고혈압 (0: 미선택, 1: 선택)",
    "ldl_f1_c": "질병 및 상해 항목 c. 요로감염 (0: 미선택, 1: 선택)",
    "ldl_f1_d": "질병 및 상해 항목 d. 말초혈관질활 (0: 미선택, 1: 선택)",
    "ldl_f1_e": "질병 및 상해 항목 e. 하지마비 (0: 미선택, 1: 선택)",
    "ldl_f1_f": "질병 및 상해 항목 f. 사지마비 (0: 미선택, 1: 선택)",
    "ldl_f1_g": "질병 및 상해 항목 g. 편마비 (0: 미선택, 1: 선택)",
    "ldl_f1_h": "질병 및 상해 항목 h. 뇌성마비 (0: 미선택, 1: 선택)",
    "ldl_f1_i": "질병 및 상해 항목 i. 뇌혈관질환 (0: 미선택, 1: 선택)",
    "ldl_f1_j": "질병 및 상해 항목 j. 파킨슨병 (0: 미선택, 1: 선택)",
    "ldl_f1_k": "질병 및 상해 항목 k. 척수손상 (0: 미선택, 1: 선택)",
    "ldl_f1_l": "질병 및 상해 항목 l. 중증근무력증 및 기타 근신경 장애 (0: 미선택, 1: 선택)",
    "ldl_f1_m": "질병 및 상해 항목 m. 근육의 원발성 장애 (0: 미선택, 1: 선택)",
    "ldl_f1_n": "질병 및 상해 항목 n. 다발경화증(0: 미선택, 1: 선택)",
    "ldl_f1_o": "질병 및 상해 항목 o. 헌틴톤병(0: 미선택, 1: 선택)",
    "ldl_f1_p": "질병 및 상해 항목 p. 유전성 운동실조(0: 미선택, 1: 선택)",
    "ldl_f1_q": "질병 및 상해 항목 q. 척수성 근육위축 및 관련 증후군(0: 미선택, 1: 선택)",
    "ldl_f1_r": "질병 및 상해 항목 r. 달리 분류된 질환에서의 일차적으로 중추신경계통에 영향을 주는 전신 위축(0: 미선택, 1: 선택)",
    "ldl_f1_s": "질병 및 상해 항목 s. 진행성 핵상안근마비(0: 미선택, 1: 선택)",
    "ldl_f1_t": "질병 및 상해 항목 t. 중추 신경계통의 비정형바이러스 감염(0: 미선택, 1: 선택)",
    "ldl_f1_u": "질병 및 상해 항목 u. 아급성 괴사성 뇌병증(0: 미선택, 1: 선택)",
    "ldl_f1_v": "질병 및 상해 항목 v. 후천성 면역결핍증(0: 미선택, 1: 선택)",
    "ldl_f1_w": "질병 및 상해 항목 w. 치매(0: 미선택, 1: 선택)",
    "ldl_f1_x": "질병 및 상해 항목 x. 고지혈증(0: 미선택, 1: 선택)",
    "ldl_f1_y": "질병 및 상해 항목 y. 심부전(0: 미선택, 1: 선택)",
    "ldl_f1_z": "질병 및 상해 항목 z. 만성폐색성폐질환(0: 미선택, 1: 선택)",
    "ldl_f1_aa": "질병 및 상해 항목 aa. 천식(0: 미선택, 1: 선택)",
    "ldl_f1_ab": "질병 및 상해 항목 ab. 해당없음 (0: 미선택, 1: 선택)",
    "ldl_f2_a": "영양관련 장애 a. 콰시오르코르(E40) (0: 미선택, 1: 선택)",
    "ldl_f2_b": "영양관련 장애 b. 영양성 소모증(E41) (0: 미선택, 1: 선택)",
    "ldl_f2_c": "영양관련 장애 c. 소모성 콰시오르코르(E42) (0: 미선택, 1: 선택)",
    "ldl_f2_d": "영양관련 장애 d. 상세불명의 중증 단백질-에너지 영양실조(E43) (0: 미선택, 1: 선택)",
    "ldl_f2_e": "영양관련 장애 e. 중등도 및 경도의 단백질-에너지 영양실조(E44) (0: 미선택, 1: 선택)",
    "ldl_f2_f": "영양관련 장애 f. 단백질-에너지 영양실조로 인한 발육지연(E45) (0: 미선택, 1: 선택)",
    "ldl_f2_g": "영양관련 장애 g. 상세불명의 단백질-에너지 영양실조(E46) (0: 미선택, 1: 선택)",
    "ldl_f2_h": "영양관련 장애 h. 해당사항 없음 (0: 미선택, 1: 선택)",
    "ldl_g1_a": "건강상태 문제 상황 a.열 (0: 미선택, 1: 선택)",
    "ldl_g1_a1": "건강상태 문제 상황 a-1. 체온",
    "ldl_g1_a2": "건강상태 문제 상황 a-2. 발열 원인을 찾는 검사와 처치 시행 여부 (0: 아니오, 1: 예)",
    "ldl_g1_a3": "건강상태 문제 상황 a-3. 발열 일수",
    "ldl_g1_b": "건강상태 문제 상황 b. 탈수 (0: 미선택, 1: 선택)",
    "ldl_g1_c": "건강상태 문제 상황 c. 구토 (0: 미선택, 1: 선택)",
    "ldl_g1_d": "건강상태 문제 상황 d. 수술3개월 이내 루 관리 (0: 미선택, 1: 선택)",
    "ldl_g1_e": "건강상태 문제 상황 e. 출혈.감염 등의 문제로 인한 루 관리 (0: 미선택, 1: 선택)",
    "ldl_g1_f": "건강상태 문제 상황 f. 해당사항없음 (0: 미선택, 1: 선택)",
    "ldl_g1_g": "해당 없음",
    "ldl_g2_a": "통증 발생 빈도 (0: 없음, 1: 매일 아님, 2: 매일)",
    "ldl_g2_b": "해당 없음",
    "ldl_g2_b1": "시각통증등급(VAS) 점수 (0-10)",
    "ldl_g2_b2": "숫자통증등급(NRS) 점수 (0-10)",
    "ldl_g2_b3": "얼굴통증등급(FPS) 점수 (0-5)",
    "ldl_g2_c": "해당 없음",
    "ldl_g2_c1": "통증관련 치료 (0: 아니오, 1: 예)",
    "ldl_g2_c2": "암성통증 치료 (0: 아니오, 1: 예)",
    "ldl_g3_a": "낙상(지난 30일 이내에 낙상) (0: 아니오, 1: 예, 2: 확인불가)",
    "ldl_g3_b": "낙상(지난 31일에서 180일 사이 낙상) (0: 아니오, 1: 예, 2: 확인불가)",
    "ldl_g4": "말기질환 (0: 아니오, 1: 예)",
    "ldl_h1": "물이나 음식 삼키기 어려움 (0: 아니오, 1: 예)",
    "ldl_h21_a": "체중측정 여부 (0: 아니오, 1: 예)",
    "ldl_h21_b1": "체중(kg)",
    "ldl_h21_b2": "체중 측정일 (YYYYMMDD)",
    "ldl_h22": "체중감소 (0: 없음, 1: 있음, 2: 확인불가)",
    "ldl_h23_a": "키 측정 여부 (0: 아니오, 1: 예)",
    "ldl_h23_b1": "키(cm)",
    "ldl_h23_b2": "키 측정일 (YYYYMMDD)",
    "ldl_h3_a": "정맥영양 여부 (0: 아니오, 1: 예)",
    "ldl_h3_b": "해당 없음",
    "ldl_h3_b1": "경관영양 여부 (0: 아니오, 1: 예)",
    "ldl_h3_b2": "경관영양 실시일수",
    "ldl_h4_a": "정맥영양 상태 (0: 없음, 1: 1~25%, 2: 26~50%, 3: 51~75%, 4.76~100%)",
    "ldl_h4_b": "영양 형태 (0: 없음, 1: 1~500ml, 2: 501~1000ml, 3: 1001~1500ml, 4: 1501~2000ml, 5: 2001ml이상)",
    "ldl_i1_a1": "1단계 욕창 개수",
    "ldl_i1_a2": "2단계 욕창 개수",
    "ldl_i1_a3": "3단계 욕창 개수",
    "ldl_i1_a4": "4단계 욕창 개수",
    "ldl_i1_b1": "1단계 울혈성 또는 허혈성 궤양 개수",
    "ldl_i1_b2": "2단계 울혈성 또는 허혈성 궤양 개수",
    "ldl_i1_b3": "3단계 울혈성 또는 허혈성 궤양 개수",
    "ldl_i1_b4": "4단계 울혈성 또는 허혈성 궤양 개수",
    "ldl_i2_a": "새로운 욕창 발생 여부 (0: 아니오, 1: 예)",
    "ldl_i2_b": "욕창 발생일 (YYYYMMDD)",
    "ldl_i3": "지난 1년사이의 욕창 과거력 (0: 없음, 1: 있음, 2: 확인불가)",
    "ldl_i4_a": "피부기타문제 a. 2도 이상의 화상 (0: 미선택, 1: 선택)",
    "ldl_i4_b": "피부기타문제 b. 개방성 피부병변 (0: 미선택, 1: 선택)",
    "ldl_i4_b1": "해당 없음",
    "ldl_i4_b2": "해당 없음",
    "ldl_i4_c": "피부기타문제 c. 수술 창상 (0: 미선택, 1: 선택)",
    "ldl_i4_d": "피부기타문제 d. 발의 감염 (0: 미선택, 1: 선택)",
    "ldl_i4_e": "피부기타문제 e. 해당사항 없음 (0: 미선택, 1: 선택)",
    "ldl_i5_a": "피부문제처치 a. 압력을 줄여주는 도구 사용 (0: 미선택, 1: 선택)",
    "ldl_i5_b": "피부문제처치 b. 체위변경 (0: 미선택, 1: 선택)",
    "ldl_i5_c": "피부문제처치 c. 피부문제를 해결하기 위한 영양공급 (0: 미선택, 1: 선택)",
    "ldl_i5_d": "피부문제처치 d. 피부궤양 드레싱 (0: 미선택, 1: 선택)",
    "ldl_i5_d1": "d. 피부궤양 드레싱(발) (0: 아니오, 1: 예)",
    "ldl_i5_d2": "d. 피부궤양 드레싱(발 이외) (0: 아니오, 1: 예)",
    "ldl_i5_e": "피부문제처치 e. 피부궤양 이외의 드레싱 (0: 미선택, 1: 선택)",
    "ldl_i5_e1": "e. 피부궤양 이외의 드레싱(발) (0: 아니오, 1: 예)",
    "ldl_i5_e2": "e. 피부궤양 이외의 드레싱(발 이외) (0: 아니오, 1: 예)",
    "ldl_i5_f": "피부문제처치 f. 수술창상 치료 (0: 미선택, 1: 선택)",
    "ldl_i5_g": "피부문제처치 g. 화상관련 처치 (0: 미선택, 1: 선택)",
    "ldl_i5_h": "피부문제처치 h. 해당사항 없음 (0: 미선택, 1: 선택)",
    "ldl_j1": "인슐린 주사제 투여 일수 (0: 투여되지 않았거나, 투여되었지만 매일은 아님, 1: 매일 1회 투여, 2: 매일 2회 이상 투여)",
    "ldl_j2": "행동심리증상 약물 사용 (0: 아니오, 1: 예)",
    "ldl_j3": "치매관련 약제 복용 (0: 아니오, 1: 예)",
    "ldl_j4": "복용한 의약품 수 (0: 없음, 1: 5개 미만, 2: 5-9개, 3: 10-14개, 4: 15개 이상)",
    "ldl_k1_a": "특수처치 a. 정맥주사에 의한 투약 (0: 미선택, 1: 선택)",
    "ldl_k1_a1": "정맥주사 투여일수",
    "ldl_k1_b": "특수처치 b. 배뇨관련 루 관리 (0: 미선택, 1: 선택)",
    "ldl_k1_c": "특수처치 c. 배변관리 루 관리 (0: 미선택, 1: 선택)",
    "ldl_k1_d": "특수처치 d. 영양관련 루 관리 (0: 미선택, 1: 선택)",
    "ldl_k1_e": "특수처치 e. 산소요법 (0: 미선택, 1: 선택)",
    "ldl_k1_e1": "산소포화도 (%)",
    "ldl_k1_e2": "산소투여 일수",
    "ldl_k1_f": "특수처치 f. 하기도 증기흡입 치료 (0: 미선택, 1: 선택)",
    "ldl_k1_g": "특수처치 g. 흡인 (0: 미선택, 1: 선택)",
    "ldl_k1_h": "특수처치 h. 기관절개관 관리 (0: 미선택, 1: 선택)",
    "ldl_k1_i": "특수처치 i. 인공호흡기 (0: 미선택, 1: 선택)",
    "ldl_k1_i1": "개인용 인공호흡기 (0: 아니오, 1: 예)",
    "ldl_k1_i2": "병원용 인공호흡기 (0: 아니오, 1: 예)",
    "ldl_k1_j": "특수처치 j. 중심정맥영양 (0: 미선택, 1: 선택)",
    "ldl_k1_j1": "해당 없음",
    "ldl_k1_j2": "해당 없음",
    "ldl_k1_k": "특수처치 k. 해당사항 없음 (0: 미선택, 1: 선택)",
    "ldl_k1_l": "해당 없음",
    "ldl_k2": "전문재활치료 실시일수 (0-7)",
}

ldl_keys = [
    "ldl_a10_a",
    "ldl_a10_b",
    "ldl_a10_c",
    "ldl_a10_d",
    "ldl_a11",
    "ldl_a12_a",
    "ldl_a12_b1",
    "ldl_a12_b2",
    "ldl_a12_b3",
    "ldl_a12_b4",
    "ldl_a12_b5",
    "ldl_a12_b6",
    "ldl_a12_b7",
    "ldl_a12_b8",
    "ldl_a13",
    "ldl_a14_a",
    "ldl_a14_b",
    "ldl_a14_c",
    "ldl_a14_d",
    "ldl_a14_e",
    "ldl_a14_f",
    "ldl_a14_g",
    "ldl_b1",
    "ldl_b2",
    "ldl_c1",
    "ldl_c2",
    "ldl_c3",
    "ldl_c4",
    "ldl_c5_a",
    "ldl_c5_b",
    "ldl_c5_c",
    "ldl_c5_d",
    "ldl_c5_e",
    "ldl_c5_f",
    "ldl_c5_g",
    "ldl_c5_h",
    "ldl_c5_i",
    "ldl_c5_j",
    "ldl_c5_k",
    "ldl_c5_l",
    "ldl_c5_m",
    "ldl_c5_n",
    "ldl_c6_a",
    "ldl_c6_b1",
    "ldl_c6_b2",
    "ldl_c7_a",
    "ldl_c7_b1",
    "ldl_c7_b2",
    "ldl_c7_c",
    "ldl_c7_d1",
    "ldl_c7_d2",
    "ldl_d1",
    "ldl_d2",
    "ldl_d3",
    "ldl_d4",
    "ldl_d5",
    "ldl_d6",
    "ldl_d7",
    "ldl_d8",
    "ldl_d9",
    "ldl_d10",
    "ldl_d11",
    "ldl_d12_a",
    "ldl_d12_b",
    "ldl_d12_c",
    "ldl_e1",
    "ldl_e2",
    "ldl_e3_a",
    "ldl_e3_b",
    "ldl_e3_c",
    "ldl_e3_d",
    "ldl_e3_e",
    "ldl_e3_f",
    "ldl_e3_g",
    "ldl_e3_g1",
    "ldl_e3_g1_1",
    "ldl_e3_g1_2",
    "ldl_e3_g2_1",
    "ldl_e3_g2_2",
    "ldl_e3_g3_1",
    "ldl_e3_g3_2",
    "ldl_e3_g4_1",
    "ldl_e3_g4_2",
    "ldl_e3_g5_1",
    "ldl_e3_g5_2",
    "ldl_e3_g6_1",
    "ldl_e3_g6_2",
    "ldl_e3_g7_1",
    "ldl_e3_g7_2",
    "ldl_e3_g8_1",
    "ldl_e3_g8_2",
    "ldl_e3_g9_1",
    "ldl_e3_g9_2",
    "ldl_e3_g10_1",
    "ldl_e3_g10_2",
    "ldl_e3_g11",
    "ldl_e3_h",
    "ldl_e4",
    "ldl_e4_a",
    "ldl_e4_b",
    "ldl_f1_a",
    "ldl_f1_a1_a",
    "ldl_f1_a1_b1",
    "ldl_f1_a1_b2",
    "ldl_f1_a2_a",
    "ldl_f1_a2_b1",
    "ldl_f1_a2_b2",
    "ldl_f1_b",
    "ldl_f1_c",
    "ldl_f1_d",
    "ldl_f1_e",
    "ldl_f1_f",
    "ldl_f1_g",
    "ldl_f1_h",
    "ldl_f1_i",
    "ldl_f1_j",
    "ldl_f1_k",
    "ldl_f1_l",
    "ldl_f1_m",
    "ldl_f1_n",
    "ldl_f1_o",
    "ldl_f1_p",
    "ldl_f1_q",
    "ldl_f1_r",
    "ldl_f1_s",
    "ldl_f1_t",
    "ldl_f1_u",
    "ldl_f1_v",
    "ldl_f1_w",
    "ldl_f1_x",
    "ldl_f1_y",
    "ldl_f1_z",
    "ldl_f1_aa",
    "ldl_f1_ab",
    "ldl_f2_a",
    "ldl_f2_b",
    "ldl_f2_c",
    "ldl_f2_d",
    "ldl_f2_e",
    "ldl_f2_f",
    "ldl_f2_g",
    "ldl_f2_h",
    "ldl_g1_a",
    "ldl_g1_a1",
    "ldl_g1_a2",
    "ldl_g1_a3",
    "ldl_g1_b",
    "ldl_g1_c",
    "ldl_g1_d",
    "ldl_g1_e",
    "ldl_g1_f",
    "ldl_g1_g",
    "ldl_g2_a",
    "ldl_g2_b",
    "ldl_g2_b1",
    "ldl_g2_b2",
    "ldl_g2_b3",
    "ldl_g2_c",
    "ldl_g2_c1",
    "ldl_g2_c2",
    "ldl_g3_a",
    "ldl_g3_b",
    "ldl_g4",
    "ldl_h1",
    "ldl_h21_a",
    "ldl_h21_b1",
    "ldl_h21_b2",
    "ldl_h22",
    "ldl_h23_a",
    "ldl_h23_b1",
    "ldl_h23_b2",
    "ldl_h3_a",
    "ldl_h3_b",
    "ldl_h3_b1",
    "ldl_h3_b2",
    "ldl_h4_a",
    "ldl_h4_b",
    "ldl_i1_a1",
    "ldl_i1_a2",
    "ldl_i1_a3",
    "ldl_i1_a4",
    "ldl_i1_b1",
    "ldl_i1_b2",
    "ldl_i1_b3",
    "ldl_i1_b4",
    "ldl_i2_a",
    "ldl_i2_b",
    "ldl_i3",
    "ldl_i4_a",
    "ldl_i4_b",
    "ldl_i4_b1",
    "ldl_i4_b2",
    "ldl_i4_c",
    "ldl_i4_d",
    "ldl_i4_e",
    "ldl_i5_a",
    "ldl_i5_b",
    "ldl_i5_c",
    "ldl_i5_d",
    "ldl_i5_d1",
    "ldl_i5_d2",
    "ldl_i5_e",
    "ldl_i5_e1",
    "ldl_i5_e2",
    "ldl_i5_f",
    "ldl_i5_g",
    "ldl_i5_h",
    "ldl_j1",
    "ldl_j2",
    "ldl_j3",
    "ldl_j4",
    "ldl_k1_a",
    "ldl_k1_a1",
    "ldl_k1_b",
    "ldl_k1_c",
    "ldl_k1_d",
    "ldl_k1_e",
    "ldl_k1_e1",
    "ldl_k1_e2",
    "ldl_k1_f",
    "ldl_k1_g",
    "ldl_k1_h",
    "ldl_k1_i",
    "ldl_k1_i1",
    "ldl_k1_i2",
    "ldl_k1_j",
    "ldl_k1_j1",
    "ldl_k1_j2",
    "ldl_k1_k",
    "ldl_k1_l",
    "ldl_k2",
]

ldl_item_dict = {
    "입원군_최고도": "ldl_etc4",
    "입원군_고도": "ldl_etc4",
    "입원군_중도": "ldl_etc4",
    "입원군_경도": "ldl_etc4",
    "입원군_선택입원": "ldl_etc4",
    "ADL": "ldl_adl",
    "장기요양등급": "ldl_a12_a",
    "혼수": "ldl_b1",
    "섬망": "ldl_b2",
    "망상": "ldl_c5_a",
    "단기기억력장애": "ldl_c1",
    "인식기술": "ldl_c2",
    "이해시키는능력": "ldl_c3",
    "의사표현": "ldl_c4",
}
